pub enum ShardStateLifeCycle {
Scope,
Shard,
}Expand description
Describes the lifecycle of this shard state.
Variants
Scope
State exists for the lifetime of one router controller instance.
Shard
State exists for the lifetime of a route instance.